\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{SIAM2017Abstract}[2016/06/09 SIAM2017Abstract]
% Written by:
% Juergen Hackl
% ETH Zurich - Chair of Infrastructure Management
% June 2015

%% Article options
\DeclareOption{10pt}{
	\PassOptionsToClass{\CurrentOption}{article}
}

%% Fallback
\DeclareOption*{
	\ClassWarning{myclass}{Unknown option '\CurrentOption'}
}

%% Custom package options
\DeclareOption{sansserif}{
	\PassOptionsToPackage{\CurrentOption}{paxcommands}
}
\DeclareOption{neverindent}{
	\PassOptionsToPackage{\CurrentOption}{paxcommands}
}

%% Execute default options
\ExecuteOptions{10pt}

%% Process given options
\ProcessOptions\relax

%% Load base class (paper in a4 format)
\LoadClass[a4paper,10pt,twocolumn=false]{article}

% Page layout
\RequirePackage[left=2.5cm,right=2.5cm,top=2.5cm,bottom=2cm]{geometry}
\RequirePackage{graphicx}
\setlength{\parindent}{0pt}
\setlength{\parskip}{3pt}

% Amsmath package
\RequirePackage{amsmath}
\RequirePackage{amstext}
\RequirePackage{amsfonts}
\RequirePackage{amssymb}
\RequirePackage{bm}

% Text encoding
\RequirePackage[utf8x]{inputenc}
\RequirePackage[T1]{fontenc}

% Fonts
\RequirePackage{helvet}% Arial font
\renewcommand{\familydefault}{\sfdefault}

% Bibliography
\RequirePackage{natbib}

% Caption formatting
\RequirePackage[font={small,it},justification=RaggedRight,singlelinecheck=false]{caption}

% Paralist
\RequirePackage{paralist}

% hyperlinks
\RequirePackage[colorlinks=true, urlcolor=black, linkcolor=black, 
citecolor=black]{hyperref}


%% Headers/footers: fancyhdr config
\RequirePackage{fancyhdr}
%\pagestyle{empty}

\pagestyle{fancy} \fancyhead{}
\fancyfoot[C]{\thepage} \fancyhead[R]{ \footnotesize SIAM 2017}
\renewcommand{\headrulewidth}{0pt}
\renewcommand{\footrulewidth}{0pt}

% Titlesec formatting
\usepackage{titlesec}
\titleformat{\section}[block]
  {\fontsize{14}{18}\bfseries}
  {}
  {0cm}
  {}
\titlespacing*{\section}{0pt}{3pt plus 1pt minus 1pt}{-3pt plus 1pt minus  1pt}

\renewcommand{\bibsection}{}

%% HEADER MACROS SECTION: REQUIRED TO COMPLETE THE TEMPLATE
% Expanding author list with the \addauthor command
\def \authlist {}
\def \affiliationlist {}
\def \corauthormail {}

\newcommand{\addauthor}[2]{
\expandafter\def\expandafter\authlist\expandafter{\authlist{}
    \fontsize{10pt}{12pt}\selectfont #1\textsuperscript{#2}; }
}

\newcommand{\addaffiliation}[2]{
\expandafter\def\expandafter\affiliationlist\expandafter{\affiliationlist{}
    \fontsize{10pt}{12pt}\textsuperscript{#1}\selectfont #2 \\ \vspace{3pt} }
}


\newcommand{\addcorauthormail}[1]{
 \expandafter\def\expandafter\corauthormail\expandafter{\corauthormail{}
    \fontsize{10pt}{12pt}\selectfont #1; }
}

% Patch to allow for text spanning on two pages columns at the beginning of the 
%document
\RequirePackage{etoolbox}
\patchcmd[\long]%   prefix
  {\@topnewpage}%   cmd
  {\@nodocument}{}% search & replace
  {}{}%             success & failure

%% Title page (header, title and authors)
\AtBeginDocument{
\vspace*{-17mm}
\includegraphics[width=\textwidth]{SIAM_header}
  \vspace{-1mm}
  \begin{center}
    \fontsize{12pt}{16pt}\selectfont\
    \bf\MakeUppercase\@title
  \end{center}
  \vspace{1ex}
  \begin{flushleft}
	\authlist\\[1mm]
    \affiliationlist
    \textsuperscript{*}Corresponding author; e-mail: \corauthormail
  \end{flushleft}
  \vspace{2ex}
  \section{Abstract}
\noindent
}

%% Add the reference section at the end of the document
%\AtEndDocument{
%
%}
\endinput